import { CodeStarClient } from "./CodeStarClient";
import { AssociateTeamMemberInput } from "./types/AssociateTeamMemberInput";
import { AssociateTeamMemberOutput } from "./types/AssociateTeamMemberOutput";
import { CreateProjectInput } from "./types/CreateProjectInput";
import { CreateProjectOutput } from "./types/CreateProjectOutput";
import { CreateUserProfileInput } from "./types/CreateUserProfileInput";
import { CreateUserProfileOutput } from "./types/CreateUserProfileOutput";
import { DeleteProjectInput } from "./types/DeleteProjectInput";
import { DeleteProjectOutput } from "./types/DeleteProjectOutput";
import { DeleteUserProfileInput } from "./types/DeleteUserProfileInput";
import { DeleteUserProfileOutput } from "./types/DeleteUserProfileOutput";
import { DescribeProjectInput } from "./types/DescribeProjectInput";
import { DescribeProjectOutput } from "./types/DescribeProjectOutput";
import { DescribeUserProfileInput } from "./types/DescribeUserProfileInput";
import { DescribeUserProfileOutput } from "./types/DescribeUserProfileOutput";
import { DisassociateTeamMemberInput } from "./types/DisassociateTeamMemberInput";
import { DisassociateTeamMemberOutput } from "./types/DisassociateTeamMemberOutput";
import { ListProjectsInput } from "./types/ListProjectsInput";
import { ListProjectsOutput } from "./types/ListProjectsOutput";
import { ListResourcesInput } from "./types/ListResourcesInput";
import { ListResourcesOutput } from "./types/ListResourcesOutput";
import { ListTagsForProjectInput } from "./types/ListTagsForProjectInput";
import { ListTagsForProjectOutput } from "./types/ListTagsForProjectOutput";
import { ListTeamMembersInput } from "./types/ListTeamMembersInput";
import { ListTeamMembersOutput } from "./types/ListTeamMembersOutput";
import { ListUserProfilesInput } from "./types/ListUserProfilesInput";
import { ListUserProfilesOutput } from "./types/ListUserProfilesOutput";
import { TagProjectInput } from "./types/TagProjectInput";
import { TagProjectOutput } from "./types/TagProjectOutput";
import { UntagProjectInput } from "./types/UntagProjectInput";
import { UntagProjectOutput } from "./types/UntagProjectOutput";
import { UpdateProjectInput } from "./types/UpdateProjectInput";
import { UpdateProjectOutput } from "./types/UpdateProjectOutput";
import { UpdateTeamMemberInput } from "./types/UpdateTeamMemberInput";
import { UpdateTeamMemberOutput } from "./types/UpdateTeamMemberOutput";
import { UpdateUserProfileInput } from "./types/UpdateUserProfileInput";
import { UpdateUserProfileOutput } from "./types/UpdateUserProfileOutput";
export declare class CodeStar extends CodeStarClient {
    /**
     * <p>Adds an IAM user to the team for an AWS CodeStar project.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {LimitExceededException} <p>A resource limit has been exceeded.</p>
     *   - {ProjectNotFoundException} <p>The specified AWS CodeStar project was not found.</p>
     *   - {TeamMemberAlreadyAssociatedException} <p>The team member is already associated with a role in this project.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {InvalidServiceRoleException} <p>The service role is not valid.</p>
     *   - {ProjectConfigurationException} <p>Project configuration information is required but not specified.</p>
     *   - {ConcurrentModificationException} <p>Another modification is being made. That modification must complete before you can make your change.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    associateTeamMember(args: AssociateTeamMemberInput): Promise<AssociateTeamMemberOutput>;
    associateTeamMember(args: AssociateTeamMemberInput, cb: (err: any, data?: AssociateTeamMemberOutput) => void): void;
    /**
     * <p>Creates a project, including project resources. This action creates a project based on a submitted project request. A set of source code files and a toolchain template file can be included with the project request. If these are not provided, an empty project is created.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ProjectAlreadyExistsException} <p>An AWS CodeStar project with the same ID already exists in this region for the AWS account. AWS CodeStar project IDs must be unique within a region for the AWS account.</p>
     *   - {LimitExceededException} <p>A resource limit has been exceeded.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {ProjectCreationFailedException} <p>The project creation request was valid, but a nonspecific exception or error occurred during project creation. The project could not be created in AWS CodeStar.</p>
     *   - {InvalidServiceRoleException} <p>The service role is not valid.</p>
     *   - {ProjectConfigurationException} <p>Project configuration information is required but not specified.</p>
     *   - {ConcurrentModificationException} <p>Another modification is being made. That modification must complete before you can make your change.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    createProject(args: CreateProjectInput): Promise<CreateProjectOutput>;
    createProject(args: CreateProjectInput, cb: (err: any, data?: CreateProjectOutput) => void): void;
    /**
     * <p>Creates a profile for a user that includes user preferences, such as the display name and email address assocciated with the user, in AWS CodeStar. The user profile is not project-specific. Information in the user profile is displayed wherever the user's information appears to other users in AWS CodeStar.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {UserProfileAlreadyExistsException} <p>A user profile with that name already exists in this region for the AWS account. AWS CodeStar user profile names must be unique within a region for the AWS account. </p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    createUserProfile(args: CreateUserProfileInput): Promise<CreateUserProfileOutput>;
    createUserProfile(args: CreateUserProfileInput, cb: (err: any, data?: CreateUserProfileOutput) => void): void;
    /**
     * <p>Deletes a project, including project resources. Does not delete users associated with the project, but does delete the IAM roles that allowed access to the project.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ConcurrentModificationException} <p>Another modification is being made. That modification must complete before you can make your change.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {InvalidServiceRoleException} <p>The service role is not valid.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteProject(args: DeleteProjectInput): Promise<DeleteProjectOutput>;
    deleteProject(args: DeleteProjectInput, cb: (err: any, data?: DeleteProjectOutput) => void): void;
    /**
     * <p>Deletes a user profile in AWS CodeStar, including all personal preference data associated with that profile, such as display name and email address. It does not delete the history of that user, for example the history of commits made by that user.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteUserProfile(args: DeleteUserProfileInput): Promise<DeleteUserProfileOutput>;
    deleteUserProfile(args: DeleteUserProfileInput, cb: (err: any, data?: DeleteUserProfileOutput) => void): void;
    /**
     * <p>Describes a project and its resources.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ProjectNotFoundException} <p>The specified AWS CodeStar project was not found.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {InvalidServiceRoleException} <p>The service role is not valid.</p>
     *   - {ProjectConfigurationException} <p>Project configuration information is required but not specified.</p>
     *   - {ConcurrentModificationException} <p>Another modification is being made. That modification must complete before you can make your change.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeProject(args: DescribeProjectInput): Promise<DescribeProjectOutput>;
    describeProject(args: DescribeProjectInput, cb: (err: any, data?: DescribeProjectOutput) => void): void;
    /**
     * <p>Describes a user in AWS CodeStar and the user attributes across all projects.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {UserProfileNotFoundException} <p>The user profile was not found.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeUserProfile(args: DescribeUserProfileInput): Promise<DescribeUserProfileOutput>;
    describeUserProfile(args: DescribeUserProfileInput, cb: (err: any, data?: DescribeUserProfileOutput) => void): void;
    /**
     * <p>Removes a user from a project. Removing a user from a project also removes the IAM policies from that user that allowed access to the project and its resources. Disassociating a team member does not remove that user's profile from AWS CodeStar. It does not remove the user from IAM.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ProjectNotFoundException} <p>The specified AWS CodeStar project was not found.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {InvalidServiceRoleException} <p>The service role is not valid.</p>
     *   - {ConcurrentModificationException} <p>Another modification is being made. That modification must complete before you can make your change.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    disassociateTeamMember(args: DisassociateTeamMemberInput): Promise<DisassociateTeamMemberOutput>;
    disassociateTeamMember(args: DisassociateTeamMemberInput, cb: (err: any, data?: DisassociateTeamMemberOutput) => void): void;
    /**
     * <p>Lists all projects in AWS CodeStar associated with your AWS account.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidNextTokenException} <p>The next token is not valid.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listProjects(args: ListProjectsInput): Promise<ListProjectsOutput>;
    listProjects(args: ListProjectsInput, cb: (err: any, data?: ListProjectsOutput) => void): void;
    /**
     * <p>Lists resources associated with a project in AWS CodeStar.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ProjectNotFoundException} <p>The specified AWS CodeStar project was not found.</p>
     *   - {InvalidNextTokenException} <p>The next token is not valid.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listResources(args: ListResourcesInput): Promise<ListResourcesOutput>;
    listResources(args: ListResourcesInput, cb: (err: any, data?: ListResourcesOutput) => void): void;
    /**
     * <p>Gets the tags for a project.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ProjectNotFoundException} <p>The specified AWS CodeStar project was not found.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {InvalidNextTokenException} <p>The next token is not valid.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listTagsForProject(args: ListTagsForProjectInput): Promise<ListTagsForProjectOutput>;
    listTagsForProject(args: ListTagsForProjectInput, cb: (err: any, data?: ListTagsForProjectOutput) => void): void;
    /**
     * <p>Lists all team members associated with a project.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ProjectNotFoundException} <p>The specified AWS CodeStar project was not found.</p>
     *   - {InvalidNextTokenException} <p>The next token is not valid.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listTeamMembers(args: ListTeamMembersInput): Promise<ListTeamMembersOutput>;
    listTeamMembers(args: ListTeamMembersInput, cb: (err: any, data?: ListTeamMembersOutput) => void): void;
    /**
     * <p>Lists all the user profiles configured for your AWS account in AWS CodeStar.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {InvalidNextTokenException} <p>The next token is not valid.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listUserProfiles(args: ListUserProfilesInput): Promise<ListUserProfilesOutput>;
    listUserProfiles(args: ListUserProfilesInput, cb: (err: any, data?: ListUserProfilesOutput) => void): void;
    /**
     * <p>Adds tags to a project.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ProjectNotFoundException} <p>The specified AWS CodeStar project was not found.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {LimitExceededException} <p>A resource limit has been exceeded.</p>
     *   - {ConcurrentModificationException} <p>Another modification is being made. That modification must complete before you can make your change.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    tagProject(args: TagProjectInput): Promise<TagProjectOutput>;
    tagProject(args: TagProjectInput, cb: (err: any, data?: TagProjectOutput) => void): void;
    /**
     * <p>Removes tags from a project.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ProjectNotFoundException} <p>The specified AWS CodeStar project was not found.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {LimitExceededException} <p>A resource limit has been exceeded.</p>
     *   - {ConcurrentModificationException} <p>Another modification is being made. That modification must complete before you can make your change.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    untagProject(args: UntagProjectInput): Promise<UntagProjectOutput>;
    untagProject(args: UntagProjectInput, cb: (err: any, data?: UntagProjectOutput) => void): void;
    /**
     * <p>Updates a project in AWS CodeStar.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ProjectNotFoundException} <p>The specified AWS CodeStar project was not found.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    updateProject(args: UpdateProjectInput): Promise<UpdateProjectOutput>;
    updateProject(args: UpdateProjectInput, cb: (err: any, data?: UpdateProjectOutput) => void): void;
    /**
     * <p>Updates a team member's attributes in an AWS CodeStar project. For example, you can change a team member's role in the project, or change whether they have remote access to project resources.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {LimitExceededException} <p>A resource limit has been exceeded.</p>
     *   - {ProjectNotFoundException} <p>The specified AWS CodeStar project was not found.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {InvalidServiceRoleException} <p>The service role is not valid.</p>
     *   - {ProjectConfigurationException} <p>Project configuration information is required but not specified.</p>
     *   - {ConcurrentModificationException} <p>Another modification is being made. That modification must complete before you can make your change.</p>
     *   - {TeamMemberNotFoundException} <p>The specified team member was not found.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    updateTeamMember(args: UpdateTeamMemberInput): Promise<UpdateTeamMemberOutput>;
    updateTeamMember(args: UpdateTeamMemberInput, cb: (err: any, data?: UpdateTeamMemberOutput) => void): void;
    /**
     * <p>Updates a user's profile in AWS CodeStar. The user profile is not project-specific. Information in the user profile is displayed wherever the user's information appears to other users in AWS CodeStar. </p>
     *
     * This operation may fail with one of the following errors:
     *   - {UserProfileNotFoundException} <p>The user profile was not found.</p>
     *   - {ValidationException} <p>The specified input is either not valid, or it could not be validated.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    updateUserProfile(args: UpdateUserProfileInput): Promise<UpdateUserProfileOutput>;
    updateUserProfile(args: UpdateUserProfileInput, cb: (err: any, data?: UpdateUserProfileOutput) => void): void;
}
